==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/LinearReferenceDetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LINEARREFERENCEEVENT_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFERENCEEVENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONDIRECTIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLOWCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTINGAT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTH" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "linearrefuom",
    "linearreferenceevent",
    "inspectiondirectioncode",
    "flowcode",
    "startingat",
    "equipmentlength"
})
@XmlRootElement(name = "LinearReferenceDetails")
public class LinearReferenceDetails {

    @XmlElement(name = "LINEARREFUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linearrefuom;
    @XmlElement(name = "LINEARREFERENCEEVENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEEVENT_Type linearreferenceevent;
    @XmlElement(name = "INSPECTIONDIRECTIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inspectiondirectioncode;
    @XmlElement(name = "FLOWCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String flowcode;
    @XmlElement(name = "STARTINGAT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY startingat;
    @XmlElement(name = "EQUIPMENTLENGTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY equipmentlength;

    /**
     * Obtient la valeur de la propriété linearrefuom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Définit la valeur de la propriété linearrefuom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Obtient la valeur de la propriété linearreferenceevent.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public LINEARREFERENCEEVENT_Type getLINEARREFERENCEEVENT() {
        return linearreferenceevent;
    }

    /**
     * Définit la valeur de la propriété linearreferenceevent.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public void setLINEARREFERENCEEVENT(LINEARREFERENCEEVENT_Type value) {
        this.linearreferenceevent = value;
    }

    /**
     * Obtient la valeur de la propriété inspectiondirectioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONDIRECTIONCODE() {
        return inspectiondirectioncode;
    }

    /**
     * Définit la valeur de la propriété inspectiondirectioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONDIRECTIONCODE(String value) {
        this.inspectiondirectioncode = value;
    }

    /**
     * Obtient la valeur de la propriété flowcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLOWCODE() {
        return flowcode;
    }

    /**
     * Définit la valeur de la propriété flowcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLOWCODE(String value) {
        this.flowcode = value;
    }

    /**
     * Obtient la valeur de la propriété startingat.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTARTINGAT() {
        return startingat;
    }

    /**
     * Définit la valeur de la propriété startingat.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTARTINGAT(QUANTITY value) {
        this.startingat = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentlength.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEQUIPMENTLENGTH() {
        return equipmentlength;
    }

    /**
     * Définit la valeur de la propriété equipmentlength.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEQUIPMENTLENGTH(QUANTITY value) {
        this.equipmentlength = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/LinearReferenceDetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LINEARREFERENCEEVENT_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFERENCEEVENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONDIRECTIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLOWCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTINGAT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTH" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "linearrefuom",
    "linearreferenceevent",
    "inspectiondirectioncode",
    "flowcode",
    "startingat",
    "equipmentlength"
})
@XmlRootElement(name = "LinearReferenceDetails")
public class LinearReferenceDetails {

    @XmlElement(name = "LINEARREFUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linearrefuom;
    @XmlElement(name = "LINEARREFERENCEEVENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEEVENT_Type linearreferenceevent;
    @XmlElement(name = "INSPECTIONDIRECTIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inspectiondirectioncode;
    @XmlElement(name = "FLOWCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String flowcode;
    @XmlElement(name = "STARTINGAT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY startingat;
    @XmlElement(name = "EQUIPMENTLENGTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY equipmentlength;

    /**
     * Gets the value of the linearrefuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Sets the value of the linearrefuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Gets the value of the linearreferenceevent property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public LINEARREFERENCEEVENT_Type getLINEARREFERENCEEVENT() {
        return linearreferenceevent;
    }

    /**
     * Sets the value of the linearreferenceevent property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public void setLINEARREFERENCEEVENT(LINEARREFERENCEEVENT_Type value) {
        this.linearreferenceevent = value;
    }

    /**
     * Gets the value of the inspectiondirectioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONDIRECTIONCODE() {
        return inspectiondirectioncode;
    }

    /**
     * Sets the value of the inspectiondirectioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONDIRECTIONCODE(String value) {
        this.inspectiondirectioncode = value;
    }

    /**
     * Gets the value of the flowcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLOWCODE() {
        return flowcode;
    }

    /**
     * Sets the value of the flowcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLOWCODE(String value) {
        this.flowcode = value;
    }

    /**
     * Gets the value of the startingat property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTARTINGAT() {
        return startingat;
    }

    /**
     * Sets the value of the startingat property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTARTINGAT(QUANTITY value) {
        this.startingat = value;
    }

    /**
     * Gets the value of the equipmentlength property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEQUIPMENTLENGTH() {
        return equipmentlength;
    }

    /**
     * Sets the value of the equipmentlength property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEQUIPMENTLENGTH(QUANTITY value) {
        this.equipmentlength = value;
    }

}
